@@ -23,7 +23,6 @@ from osc_lib.command import command
 from osc_lib import exceptions as exc
 from osc_lib import utils
 from oslo_utils import strutils
-import six
 
 from senlinclient.common.i18n import _
 from senlinclient.common import utils as senlin_utils
@@ -244,9 +243,11 @@ class UpdateCluster(command.ShowOne):
         parser.add_argument(
             '--config',
             metavar='<"key1=value1;key2=value2...">',
-            help=_('s of the cluster. Default to {}. '
+            help=_('Configuration of the cluster. '
                    'This can be specified multiple times, or once with '
-                   'key-value pairs separated by a semicolon.'),
+                   'key-value pairs separated by a semicolon. '
+                   'Any existing configuration values on the cluster are '
+                   'wiped out when using this option.'),
             action='append'
         )
         parser.add_argument(
@@ -304,6 +305,7 @@ class UpdateCluster(command.ShowOne):
                 strict=True,
             ),
             'metadata': senlin_utils.format_parameters(parsed_args.metadata),
+            'config': senlin_utils.format_parameters(parsed_args.config),
             'timeout': parsed_args.timeout,
         }
 
@@ -363,7 +365,7 @@ class DeleteCluster(command.Command):
                     cid, False, parsed_args.force_delete)
                 result[cid] = ('OK', cluster_delete_action['id'])
             except Exception as ex:
-                result[cid] = ('ERROR', six.text_type(ex))
+                result[cid] = ('ERROR', str(ex))
 
         for rid, res in result.items():
             senlin_utils.print_action_result(rid, res)
